@@ -1,6 +1,6 @@
 ## ----echo = FALSE-----------------------------------------------------------------------------------------------------
 oldoptions <- options()
-oldpar <- par()
+oldpar <- par(no.readonly = TRUE)
 options(width = 120)
 
 ## ----example11, echo=TRUE, message=FALSE------------------------------------------------------------------------------
